v1alpha1

package
v0.0.0-...-43c6656 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 28, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package v1alpha1 contains API Schema definitions for the annoying v1alpha1 API group +kubebuilder:object:generate=true +groupName=annoying.getting.coffee

Index

Constants

This section is empty.

Variables

var (
	// GroupVersion is group version used to register these objects
	GroupVersion = schema.GroupVersion{Group: "annoying.getting.coffee", Version: "v1alpha1"}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)

Functions

This section is empty.

Types

type Annoyance

type Annoyance struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   AnnoyanceSpec   `json:"spec,omitempty"`
	Status AnnoyanceStatus `json:"status,omitempty"`
}

Annoyance is the Schema for the annoyances API

func (*Annoyance) DeepCopy

func (in *Annoyance) DeepCopy() *Annoyance

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Annoyance.

func (*Annoyance) DeepCopyInto

func (in *Annoyance) DeepCopyInto(out *Annoyance)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*Annoyance) DeepCopyObject

func (in *Annoyance) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type AnnoyanceList

type AnnoyanceList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []Annoyance `json:"items"`
}

AnnoyanceList contains a list of Annoyance

func (*AnnoyanceList) DeepCopy

func (in *AnnoyanceList) DeepCopy() *AnnoyanceList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnnoyanceList.

func (*AnnoyanceList) DeepCopyInto

func (in *AnnoyanceList) DeepCopyInto(out *AnnoyanceList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*AnnoyanceList) DeepCopyObject

func (in *AnnoyanceList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type AnnoyanceNuance

type AnnoyanceNuance string
const NuanceNetworkPolicy AnnoyanceNuance = "networkpolicy"
const NuancePublishingStrategy AnnoyanceNuance = "publishingstrategy"

type AnnoyanceSpec

type AnnoyanceSpec struct {

	// Nuance is the type of annoyances to inject. Supported nuances: publishingstrategy, networkpolicy
	Nuance []AnnoyanceNuance `json:"nuance,omitempty"`
}

AnnoyanceSpec defines the desired state of Annoyance

func (*AnnoyanceSpec) DeepCopy

func (in *AnnoyanceSpec) DeepCopy() *AnnoyanceSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnnoyanceSpec.

func (*AnnoyanceSpec) DeepCopyInto

func (in *AnnoyanceSpec) DeepCopyInto(out *AnnoyanceSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type AnnoyanceStatus

type AnnoyanceStatus struct {
}

AnnoyanceStatus defines the observed state of Annoyance

func (*AnnoyanceStatus) DeepCopy

func (in *AnnoyanceStatus) DeepCopy() *AnnoyanceStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnnoyanceStatus.

func (*AnnoyanceStatus) DeepCopyInto

func (in *AnnoyanceStatus) DeepCopyInto(out *AnnoyanceStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to